"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .collectionresponse import CollectionResponse, CollectionResponseTypedDict
from lambdadb.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListCollectionsResponseTypedDict(TypedDict):
    r"""A list of collections matched with a projectName."""

    collections: List[CollectionResponseTypedDict]


class ListCollectionsResponse(BaseModel):
    r"""A list of collections matched with a projectName."""

    collections: List[CollectionResponse]
