"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from lambdadb.types import BaseModel
import pydantic
from typing import List
from typing_extensions import Annotated, TypedDict


class PartitionFilterTypedDict(TypedDict):
    field: str
    r"""Partition field name."""
    in_: List[str]
    r"""Partition values to filter."""


class PartitionFilter(BaseModel):
    field: str
    r"""Partition field name."""

    in_: Annotated[List[str], pydantic.Field(alias="in")]
    r"""Partition values to filter."""
